@@ -17,12 +17,13 @@
 
 #include "b200_impl.hpp"
 #include "b200_regs.hpp"
+#include <uhd/config.hpp>
 #include <uhd/transport/usb_control.hpp>
 #include <uhd/utils/msg.hpp>
 #include <uhd/utils/cast.hpp>
 #include <uhd/exception.hpp>
 #include <uhd/utils/static.hpp>
-#include <uhd/utils/images.hpp>
+#include <uhd/utils/paths.hpp>
 #include <uhd/utils/safe_call.hpp>
 #include <uhd/usrp/dboard_eeprom.hpp>
 #include <boost/format.hpp>
@@ -85,7 +86,9 @@ static device_addrs_t b200_find(const device_addr_t &hint)
 
     //Return an empty list of addresses when an address or resource is specified,
     //since an address and resource is intended for a different, non-USB, device.
-    if (hint.has_key("addr") || hint.has_key("resource")) return b200_addrs;
+    BOOST_FOREACH(device_addr_t hint_i, separate_device_addr(hint)) {
+        if (hint_i.has_key("addr") || hint_i.has_key("resource")) return b200_addrs;
+    }
 
     boost::uint16_t vid, pid;
 
@@ -109,13 +112,11 @@ static device_addrs_t b200_find(const device_addr_t &hint)
         //extract the firmware path for the b200
         std::string b200_fw_image;
         try{
-            b200_fw_image = find_image_path(hint.get("fw", B200_FW_FILE_NAME));
+            b200_fw_image = hint.get("fw", B200_FW_FILE_NAME);
+            b200_fw_image = uhd::find_image_path(b200_fw_image, STR(UHD_IMAGES_DIR)); // FIXME
         }
-        catch(...){
-            UHD_MSG(warning) << boost::format(
-                "Could not locate B200 firmware.\n"
-                "Please install the images package. %s\n"
-            ) % print_images_error();
+        catch(uhd::exception &e){
+            UHD_MSG(warning) << e.what();
             return b200_addrs;
         }
         UHD_LOG << "the firmware image: " << b200_fw_image << std::endl;
@@ -630,7 +631,9 @@ void b200_impl::setup_radio(const size_t dspno)
         const fs_path rf_fe_path = mb_path / "dboards" / "A" / (x+"_frontends") / (dspno? "B" : "A");
 
         _tree->create<std::string>(rf_fe_path / "name").set("FE-"+key);
-        _tree->create<int>(rf_fe_path / "sensors"); //empty TODO
+        _tree->create<int>(rf_fe_path / "sensors");
+        _tree->create<sensor_value_t>(rf_fe_path / "sensors" / "lo_locked")
+            .publish(boost::bind(&b200_impl::get_fe_pll_locked, this, x == "tx"));
         BOOST_FOREACH(const std::string &name, ad9361_ctrl::get_gain_names(key))
         {
             _tree->create<meta_range_t>(rf_fe_path / "gains" / name / "range")
@@ -655,7 +658,7 @@ void b200_impl::setup_radio(const size_t dspno)
         _tree->create<meta_range_t>(rf_fe_path / "freq" / "range")
             .publish(boost::bind(&ad9361_ctrl::get_rf_freq_range));
 
-        //setup antenna stuff
+        //setup RX related stuff
         if (key[0] == 'R')
         {
             static const std::vector<std::string> ants = boost::assign::list_of("TX/RX")("RX2");
@@ -663,6 +666,8 @@ void b200_impl::setup_radio(const size_t dspno)
             _tree->create<std::string>(rf_fe_path / "antenna" / "value")
                 .subscribe(boost::bind(&b200_impl::update_antenna_sel, this, dspno, _1))
                 .set("RX2");
+            _tree->create<sensor_value_t>(rf_fe_path / "sensors" / "rssi")
+                .publish(boost::bind(&ad9361_ctrl::get_rssi, _codec_ctrl, key));
         }
         if (key[0] == 'T')
         {
@@ -779,11 +784,11 @@ void b200_impl::check_fw_compat(void)
 
     if (compat_major != B200_FW_COMPAT_NUM_MAJOR){
         throw uhd::runtime_error(str(boost::format(
-            "Expected firmware compatibility number 0x%x, but got 0x%x.%x:\n"
+            "Expected firmware compatibility number %d.%d, but got %d.%d:\n"
             "The firmware build is not compatible with the host code build.\n"
             "%s"
-        ) % int(B200_FW_COMPAT_NUM_MAJOR) % compat_major % compat_minor
-          % print_images_error()));
+        )   % int(B200_FW_COMPAT_NUM_MAJOR) % int(B200_FW_COMPAT_NUM_MINOR)
+            % compat_major % compat_minor % print_utility_error("uhd_images_downloader.py")));
     }
     _tree->create<std::string>("/mboards/0/fw_version").set(str(boost::format("%u.%u")
                 % compat_major % compat_minor));
@@ -800,11 +805,10 @@ void b200_impl::check_fpga_compat(void)
 
     if (compat_major != B200_FPGA_COMPAT_NUM){
         throw uhd::runtime_error(str(boost::format(
-            "Expected FPGA compatibility number 0x%x, but got 0x%x.%x:\n"
+            "Expected FPGA compatibility number %d, but got %d:\n"
             "The FPGA build is not compatible with the host code build.\n"
             "%s"
-        ) % int(B200_FPGA_COMPAT_NUM) % compat_major % compat_minor
-          % print_images_error()));
+        ) % int(B200_FPGA_COMPAT_NUM) % compat_major % print_utility_error("uhd_images_downloader.py")));
     }
     _tree->create<std::string>("/mboards/0/fpga_version").set(str(boost::format("%u.%u")
                 % compat_major % compat_minor));
@@ -998,3 +1002,10 @@ sensor_value_t b200_impl::get_ref_locked(void)
     const bool lock = (_local_ctrl->peek32(RB32_CORE_MISC) & 0x1) == 0x1;
     return sensor_value_t("Ref", lock, "locked", "unlocked");
 }
+
+sensor_value_t b200_impl::get_fe_pll_locked(const bool is_tx)
+{
+    const boost::uint32_t st = _local_ctrl->peek32(RB32_CORE_PLL);
+    const bool locked = is_tx ? st & 0x1 : st & 0x2;
+    return sensor_value_t("LO", locked, "locked", "unlocked");
+}
