@@ -28,7 +28,7 @@
 #include <uhd/utils/msg.hpp>
 #include <uhd/utils/log.hpp>
 #include <uhd/utils/static.hpp>
-#include <uhd/utils/images.hpp>
+#include <uhd/utils/paths.hpp>
 #include <uhd/usrp/dboard_eeprom.hpp>
 #include <uhd/transport/if_addrs.hpp>
 #include <uhd/transport/udp_zero_copy.hpp>
@@ -381,7 +381,7 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
         } catch (std::exception &e) {
             UHD_MSG(error) << "An error occured making GPSDO control: " << e.what() << std::endl;
         }
-        _sensor_manager = e300_sensor_manager::make_local(_gps);
+        _sensor_manager = e300_sensor_manager::make_local(_gps, _global_regs);
     }
     UHD_MSG(status) << (_sensor_manager->get_gps_found() ? "found" : "not found")  << std::endl;
 
@@ -397,7 +397,7 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
             "%s"
         ) % fpga::COMPAT_MAJOR
           % _get_version(FPGA_MAJOR) % _get_version(FPGA_MINOR)
-          % print_images_error()));
+          % print_utility_error("uhd_images_downloader.py")));
     }
 
     ////////////////////////////////////////////////////////////////////
@@ -493,14 +493,15 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
         .subscribe(boost::bind(&time_core_3000::set_time_next_pps, _radio_perifs[1].time64, _1));
     //setup time source props
     _tree->create<std::string>(mb_path / "time_source" / "value")
-        .subscribe(boost::bind(&e300_impl::_update_time_source, this, _1));
-    static const std::vector<std::string> time_sources = boost::assign::list_of("none")("external")("gpsdo");
+        .subscribe(boost::bind(&e300_impl::_update_time_source, this, _1))
+        .set(e300::DEFAULT_TIME_SRC);
+    static const std::vector<std::string> time_sources = boost::assign::list_of("none")("internal")("external")("gpsdo");
     _tree->create<std::vector<std::string> >(mb_path / "time_source" / "options").set(time_sources);
     //setup reference source props
     _tree->create<std::string>(mb_path / "clock_source" / "value")
-        .subscribe(boost::bind(&e300_impl::_update_clock_source, this, _1));
-    static const std::vector<std::string> clock_sources = boost::assign::list_of("internal");
-    // not implemented ("external")("gpsdo");
+        .subscribe(boost::bind(&e300_impl::_update_clock_source, this, _1))
+        .set(e300::DEFAULT_CLOCK_SRC);
+    static const std::vector<std::string> clock_sources = boost::assign::list_of("internal"); //external,gpsdo not supported
     _tree->create<std::vector<std::string> >(mb_path / "clock_source" / "options").set(clock_sources);
 
     ////////////////////////////////////////////////////////////////////
@@ -573,29 +574,6 @@ e300_impl::e300_impl(const uhd::device_addr_t &device_addr)
     }
     _tree->access<subdev_spec_t>(mb_path / "rx_subdev_spec").set(rx_spec);
     _tree->access<subdev_spec_t>(mb_path / "tx_subdev_spec").set(tx_spec);
-
-    if (_sensor_manager->get_gps_found()) {
-        _tree->access<std::string>(mb_path / "clock_source" / "value").set("gpsdo");
-        _tree->access<std::string>(mb_path / "time_source" / "value").set("gpsdo");
-        UHD_MSG(status) << "References initialized to GPSDO sources" << std::endl;
-        const time_t tp = time_t(_sensor_manager->get_gps_time().to_int());
-        _tree->access<time_spec_t>(mb_path / "time" / "pps").set(time_spec_t(tp));
-        //wait for time to be set (timeout after 1 second)
-        for (int i = 0; i < 10; i++)
-        {
-            boost::this_thread::sleep(boost::posix_time::milliseconds(100));
-            if(tp == (_tree->access<time_spec_t>(mb_path / "time" / "pps").get()).get_full_secs())
-                break;
-        }
-    } else {
-        // init to default time and clock source
-        _tree->access<std::string>(mb_path / "clock_source" / "value").set(
-            e300::DEFAULT_CLOCK_SRC);
-        _tree->access<std::string>(mb_path / "time_source" / "value").set(
-            e300::DEFAULT_TIME_SRC);
-
-            UHD_MSG(status) << "References initialized to internal sources" << std::endl;
-    }
 }
 
 boost::uint8_t e300_impl::_get_internal_gpio(
@@ -681,35 +659,6 @@ double e300_impl::_set_tick_rate(const double rate)
     return _tick_rate;
 }
 
-void e300_impl::_load_fpga_image(const std::string &path)
-{
-    if (not fs::exists("/dev/xdevcfg"))
-    {
-        ::system("mknod /dev/xdevcfg c 259 0");
-        //throw uhd::runtime_error("no xdevcfg, please run: mknod /dev/xdevcfg c 259 0");
-    }
-
-    UHD_MSG(status) << "Loading FPGA image: " << path << "..." << std::flush;
-
-    std::ifstream fpga_file(path.c_str(), std::ios_base::binary);
-    UHD_ASSERT_THROW(fpga_file.good());
-
-    std::FILE *wfile;
-    wfile = std::fopen("/dev/xdevcfg", "wb");
-    UHD_ASSERT_THROW(!(wfile == NULL));
-
-    char buff[16384]; // devcfg driver can't handle huge writes
-    do {
-        fpga_file.read(buff, sizeof(buff));
-        std::fwrite(buff, 1, fpga_file.gcount(), wfile);
-    } while (fpga_file);
-
-    fpga_file.close();
-    std::fclose(wfile);
-
-    UHD_MSG(status) << " done" << std::endl;
-}
-
 void e300_impl::_register_loopback_self_test(wb_iface::sptr iface)
 {
     bool test_fail = false;
@@ -924,14 +873,20 @@ e300_impl::both_xports_t e300_impl::_make_transport(
     return xports;
 }
 
-void e300_impl::_update_clock_source(const std::string &)
+void e300_impl::_update_clock_source(const std::string &source)
 {
+    if (source != "internal") {
+        throw uhd::value_error(boost::str(
+            boost::format("Clock source option not supported: %s. The only value supported is \"internal\". " \
+                          "To discipline the internal oscillator, set the appropriate time source.") % source
+        ));
+    }
 }
 
 void e300_impl::_update_antenna_sel(const size_t &which, const std::string &ant)
 {
     if (ant != "TX/RX" and ant != "RX2")
-        throw uhd::value_error("e300: unknown RX antenna option: " + ant);
+        throw uhd::value_error("Unknown RX antenna option: " + ant);
     _radio_perifs[which].ant_rx2 = (ant == "RX2");
     this->_update_atrs();
 }
@@ -1097,14 +1052,15 @@ void e300_impl::_setup_radio(const size_t dspno)
         _tree->create<meta_range_t>(rf_fe_path / "freq" / "range")
             .publish(boost::bind(&ad9361_ctrl::get_rf_freq_range));
 
-        //setup antenna stuff
+        //setup RX related stuff
         if (key[0] == 'R') {
             static const std::vector<std::string> ants = boost::assign::list_of("TX/RX")("RX2");
             _tree->create<std::vector<std::string> >(rf_fe_path / "antenna" / "options").set(ants);
             _tree->create<std::string>(rf_fe_path / "antenna" / "value")
                 .subscribe(boost::bind(&e300_impl::_update_antenna_sel, this, dspno, _1))
                 .set("RX2");
-
+            _tree->create<sensor_value_t>(rf_fe_path / "sensors" / "rssi")
+                .publish(boost::bind(&ad9361_ctrl::get_rssi, _codec_ctrl, key));
         }
         if (key[0] == 'T') {
             static const std::vector<std::string> ants(1, "TX/RX");
